@@ -9,25 +9,29 @@ from deeprank.features import FeatureClass
 
 class AtomicFeature(FeatureClass):
 
-    def __init__(self, pdbfile, param_charge=None, param_vdw=None,
-                 patch_file=None, contact_cutoff=8.5, verbose=False):
+    def __init__(self, pdbfile, chain1='A', chain2='B', param_charge=None,
+                param_vdw=None, patch_file=None, contact_cutoff=8.5,
+                verbose=False):
         """Compute the Coulomb, van der Waals interaction and charges.
 
         Args:
 
             pdbfile (str): pdb file of the molecule
 
+            chain1 (str): First chain ID, defaults to 'A'
+            chain2 (str): Second chain ID, defaults to 'B'
+
             param_charge (str): file name of the force field file
                 containing the charges e.g. protein-allhdg5.4_new.top.
                 Must be of the format:
-                    * CYM  atom O   type=O      charge=-0.500 end
-                    * ALA    atom N   type=NH1     charge=-0.570 end
+                * CYM  atom O   type=O      charge=-0.500 end
+                * ALA    atom N   type=NH1     charge=-0.570 end
 
             param_vdw (str): file name of the force field containing
                 vdw parameters e.g. protein-allhdg5.4_new.param.
                 Must be of the format:
-                    * NONBonded  CYAA    0.105   3.750       0.013    3.750
-                    * NONBonded  CCIS    0.105   3.750       0.013    3.750
+                * NONBonded  CYAA    0.105   3.750       0.013    3.750
+                * NONBonded  CCIS    0.105   3.750       0.013    3.750
 
             patch_file (str): file name of a valid patch file for
                 the parameters e.g. patch.top.
@@ -40,34 +44,36 @@ class AtomicFeature(FeatureClass):
             verbose (bool): print or not.
 
         Examples:
-        >>> pdb = '1AK4_100w.pdb'
-        >>>
-        >>> # get the force field included in deeprank
-        >>> # if another FF has been used to compute the ref
-        >>> # change also this path to the correct one
-        >>> FF = pkg_resources.resource_filename(
-        >>>     'deeprank.features','') + '/forcefield/'
-        >>>
-        >>> # declare the feature calculator instance
-        >>> atfeat = AtomicFeature(pdb,
-        >>>    param_charge = FF + 'protein-allhdg5-4_new.top',
-        >>>    param_vdw    = FF + 'protein-allhdg5-4_new.param',
-        >>>    patch_file   = FF + 'patch.top')
-        >>>
-        >>> # assign parameters
-        >>> atfeat.assign_parameters()
-        >>>
-        >>> # only compute the pair interactions here
-        >>> atfeat.evaluate_pair_interaction(save_interactions=test_name)
-        >>>
-        >>> # close the db
-        >>> atfeat.sqldb._close()
+            >>> pdb = '1AK4_100w.pdb'
+            >>>
+            >>> # get the force field included in deeprank
+            >>> # if another FF has been used to compute the ref
+            >>> # change also this path to the correct one
+            >>> FF = pkg_resources.resource_filename(
+            >>>     'deeprank.features','') + '/forcefield/'
+            >>>
+            >>> # declare the feature calculator instance
+            >>> atfeat = AtomicFeature(pdb,
+            >>>    param_charge = FF + 'protein-allhdg5-4_new.top',
+            >>>    param_vdw    = FF + 'protein-allhdg5-4_new.param',
+            >>>    patch_file   = FF + 'patch.top')
+            >>>
+            >>> # assign parameters
+            >>> atfeat.assign_parameters()
+            >>>
+            >>> # only compute the pair interactions here
+            >>> atfeat.evaluate_pair_interaction(save_interactions=test_name)
+            >>>
+            >>> # close the db
+            >>> atfeat.sqldb._close()
         """
 
         super().__init__("Atomic")
 
         # set a few things
         self.pdbfile = pdbfile
+        self.chain1 = chain1
+        self.chain2 = chain2
         self.param_charge = param_charge
         self.param_vdw = param_vdw
         self.patch_file = patch_file
@@ -106,11 +112,11 @@ class AtomicFeature(FeatureClass):
     def read_charge_file(self):
         """Read the .top file given in entry.
 
-        This function creates :
+        This function creates:
 
-        - self.charge : dictionary  {(resname,atname):charge}
-        - self.valid_resnames : list ['VAL','ALP', .....]
-        - self.at_name_type_convertor : dict {(resname,atname):attype}
+        - self.charge: dictionary  {(resname,atname):charge}
+        - self.valid_resnames: list ['VAL','ALP', .....]
+        - self.at_name_type_convertor: dict {(resname,atname):attype}
         """
 
         with open(self.param_charge) as f:
@@ -153,8 +159,8 @@ class AtomicFeature(FeatureClass):
 
         This function creates
 
-            - self.patch_charge : Dict {(resName,atName) : charge}
-            - self.patch_type   : Dict {(resName,atName) : type}
+            - self.patch_charge: Dict {(resName,atName): charge}
+            - self.patch_type : Dict {(resName,atName): type}
         """
 
         with open(self.patch_file) as f:
@@ -191,7 +197,7 @@ class AtomicFeature(FeatureClass):
 
         This function creates
 
-            - self.vdw : dictionary {attype:[E1,S1]}
+            - self.vdw: dictionary {attype:[E1,S1]}
         """
 
         with open(self.param_vdw) as f:
@@ -222,16 +228,16 @@ class AtomicFeature(FeatureClass):
         # but need to add a filter parameter to filter out ligand.
 
         # position of the chains
-        xyz1 = np.array(self.sqldb.get('x,y,z', chainID='A'))
-        xyz2 = np.array(self.sqldb.get('x,y,z', chainID='B'))
+        xyz1 = np.array(self.sqldb.get('x,y,z', chainID=self.chain1))
+        xyz2 = np.array(self.sqldb.get('x,y,z', chainID=self.chain2))
 
         # rowID of the chains
-        index_a = self.sqldb.get('rowID', chainID='A')
-        index_b = self.sqldb.get('rowID', chainID='B')
+        index_a = self.sqldb.get('rowID', chainID=self.chain1)
+        index_b = self.sqldb.get('rowID', chainID=self.chain2)
 
         # resName of the chains
-        resName1 = np.array(self.sqldb.get('resName', chainID='A'))
-        resName2 = np.array(self.sqldb.get('resName', chainID='B'))
+        resName1 = np.array(self.sqldb.get('resName', chainID=self.chain1))
+        resName2 = np.array(self.sqldb.get('resName', chainID=self.chain2))
 
         # declare the contact atoms
         self.contact_atoms_A = []
@@ -536,7 +542,7 @@ class AtomicFeature(FeatureClass):
             charge_data[key] = [charge[i]]
 
             # xyz format
-            chain_dict = [{'A': 0, 'B': 1}[key[0]]]
+            chain_dict = [{self.chain1: 0, self.chain2: 1}[key[0]]]
             key = tuple(chain_dict + xyz[i, :].tolist())
             charge_data_xyz[key] = [charge[i]]
 
@@ -582,8 +588,8 @@ class AtomicFeature(FeatureClass):
         vdw_data_xyz = {}
 
         # define the matrices
-        natA, natB = len(self.sqldb.get('x', chainID='A')), len(
-            self.sqldb.get('x', chainID='B'))
+        natA, natB = len(self.sqldb.get('x', chainID=self.chain1)), len(
+            self.sqldb.get('x', chainID=self.chain2))
         matrix_elec = np.zeros((natA, natB))
         matrix_vdw = np.zeros((natA, natB))
 
@@ -753,16 +759,16 @@ class AtomicFeature(FeatureClass):
 
         else:
 
-            xyzA = np.array(self.sqldb.get('x,y,z', chainID='A'))
-            xyzB = np.array(self.sqldb.get('x,y,z', chainID='B'))
+            xyzA = np.array(self.sqldb.get('x,y,z', chainID=self.chain1))
+            xyzB = np.array(self.sqldb.get('x,y,z', chainID=self.chain2))
 
-            chargeA = np.array(self.sqldb.get('CHARGE', chainID='A'))
-            chargeB = np.array(self.sqldb.get('CHARGE', chainID='B'))
+            chargeA = np.array(self.sqldb.get('CHARGE', chainID=self.chain1))
+            chargeB = np.array(self.sqldb.get('CHARGE', chainID=self.chain2))
 
             atinfoA = self.sqldb.get(
-                self.atom_key, chainID='A')
+                self.atom_key, chainID=self.chain1)
             atinfoB = self.sqldb.get(
-                self.atom_key, chainID='B')
+                self.atom_key, chainID=self.chain2)
 
         natA, natB = len(xyzA), len(xyzB)
         matrix = np.zeros((natA, natB))
@@ -837,19 +843,19 @@ class AtomicFeature(FeatureClass):
 
         else:
 
-            xyzA = np.array(self.sqldb.get('x,y,z', chainID='A'))
-            xyzB = np.array(self.sqldb.get('x,y,z', chainID='B'))
+            xyzA = np.array(self.sqldb.get('x,y,z', chainID=self.chain1))
+            xyzB = np.array(self.sqldb.get('x,y,z', chainID=self.chain2))
 
-            vdwA = np.array(self.sqldb.get('eps,sig', chainID='A'))
-            vdwB = np.array(self.sqldb.get('eps,sig', chainID='B'))
+            vdwA = np.array(self.sqldb.get('eps,sig', chainID=self.chain1))
+            vdwB = np.array(self.sqldb.get('eps,sig', chainID=self.chain2))
 
             epsA, sigA = vdwA[:, 0], vdwA[:, 1]
             epsB, sigB = vdwB[:, 0], vdwB[:, 1]
 
             atinfoA = self.sqldb.get(
-                self.atom_key, chainID='A')
+                self.atom_key, chainID=self.chain1)
             atinfoB = self.sqldb.get(
-                self.atom_key, chainID='B')
+                self.atom_key, chainID=self.chain2)
 
         natA, natB = len(xyzA), len(xyzB)
         matrix = np.zeros((natA, natB))
@@ -908,18 +914,22 @@ class AtomicFeature(FeatureClass):
 #
 ########################################################################
 
-def __compute_feature__(pdb_data, featgrp, featgrp_raw):
+def __compute_feature__(pdb_data, featgrp, featgrp_raw, chain1, chain2):
     """Main function called in deeprank for the feature calculations.
 
     Args:
         pdb_data (list(bytes)): pdb information
         featgrp (str): name of the group where to save xyz-val data
         featgrp_raw (str): name of the group where to save human readable data
+        chain1 (str): First chain ID
+        chain2 (str): Second chain ID
     """
     path = os.path.dirname(os.path.realpath(__file__))
     FF = path + '/forcefield/'
 
     atfeat = AtomicFeature(pdb_data,
+                           chain1=chain1,
+                           chain2=chain2,
                            param_charge=FF + 'protein-allhdg5-4_new.top',
                            param_vdw=FF + 'protein-allhdg5-4_new.param',
                            patch_file=FF + 'patch.top')
@@ -965,7 +975,7 @@ if __name__ == '__main__':
     atfeat.assign_parameters()
     atfeat.evaluate_pair_interaction()
     atfeat.evaluate_charges(extend_contact_to_residue=True)
-    atfeat.sqldb.close()
+    atfeat.sqldb._close()
 
     # export in the hdf5 file
     pprint(atfeat.feature_data)
