@@ -7,7 +7,7 @@ from deeprank.targets import rmsd_fnat
 
 
 def __compute_target__(decoy, targrp):
-    """calculate CAPRI class.
+    """Calculate CAPRI class.
 
         CAPRI class name and ID:
             - 'high': 0
@@ -44,4 +44,4 @@ def __compute_target__(decoy, targrp):
 
     label = StructureSimilarity.compute_CapriClass(
                 vals['FNAT'], vals['LRMSD'], vals['IRMSD'])
-    targrp.create_dataset(tarname, data=np.array(categories[label]))
\ No newline at end of file
+    targrp.create_dataset(tarname, data=np.array(categories[label]))
